From 2960ea13adf5d95b4bb2f6869d59186b2c9b2158 Mon Sep 17 00:00:00 2001
From: Aaron LI <aly@aaronly.me>
Date: Tue, 25 Jul 2017 09:32:12 +0800
Subject: clusters/halo: Change config "eta_turb" to "beta_turb"

This configuration option "beta_turb" has different meaning as
"eta_turb" in [Cassano & Brunetti 2005], though they can both be an
indicator for the turbulence acceleration efficiency.

Rename this configuration option to make the difference more clear.

Signed-off-by: Aaron LI <aly@aaronly.me>
---
 fg21sim/configs/20-extragalactic.conf.spec | 5 ++---
 fg21sim/extragalactic/clusters/halo.py     | 6 +++---
 2 files changed, 5 insertions(+), 6 deletions(-)

(limited to 'fg21sim')

diff --git a/fg21sim/configs/20-extragalactic.conf.spec b/fg21sim/configs/20-extragalactic.conf.spec
index b35507e..a48dbee 100644
--- a/fg21sim/configs/20-extragalactic.conf.spec
+++ b/fg21sim/configs/20-extragalactic.conf.spec
@@ -65,9 +65,8 @@
 
   # Emission of giant radio halos from galaxy clusters
   [[halos]]
-  # Fraction of the turbulence energy in the form of magneto-sonic waves,
-  # which will channel into relativistic electrons.
-  eta_turb = float(default=0.3, min=0.0, max=1.0)
+  # Intensity of the turbulence acceleration.
+  beta_turb = float(default=0.3, min=0.1, max=2.0)
 
   # Ratio of the total energy injected into cosmic-ray electrons during
   # the cluster life to its total thermal energy.
diff --git a/fg21sim/extragalactic/clusters/halo.py b/fg21sim/extragalactic/clusters/halo.py
index ce4bcaf..7c52f97 100644
--- a/fg21sim/extragalactic/clusters/halo.py
+++ b/fg21sim/extragalactic/clusters/halo.py
@@ -111,7 +111,7 @@ class RadioHalo:
 
     def _set_configs(self):
         comp = "extragalactic/halos"
-        self.eta_turb = self.configs.getn(comp+"/eta_turb")
+        self.beta_turb = self.configs.getn(comp+"/beta_turb")
         self.eta_e = self.configs.getn(comp+"/eta_e")
         self.gamma_min = self.configs.getn(comp+"/gamma_min")
         self.gamma_max = self.configs.getn(comp+"/gamma_max")
@@ -327,7 +327,7 @@ class RadioHalo:
         A reference value of the acceleration time due to TTD
         (transit-time damping) resonance is ~0.1 Gyr (Ref.[brunetti2011],
         Eq.(27) below); the formula derived by [cassano2005] (Eq.(40))
         has a dependence on ``eta_turb``.
 
         NOTE
         ----
@@ -348,7 +348,7 @@ class RadioHalo:
         if t > self.age_merger + self.time_crossing:
             tau = tau_max
         else:
-            tau = tau_ref / self.eta_turb
+            tau = tau_ref / self.beta_turb
         return tau
 
     @property
@@ -327,7 +327,7 @@ class RadioHalo:
         (transit-time damping) resonance is ~0.1 Gyr (Ref.[brunetti2011],
         Eq.(27) below); the formula derived by [cassano2005] (Eq.(40))
-        has a dependence on ``eta_turb``.
+        has a dependence on ``beta_turb``.
 
         NOTE
-- 
cgit v1.2.2